==> haskell-floskell-0.10.8-131-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 floskell
version:              0.10.8
visibility:           public
id:                   floskell-0.10.8-79PNgepw182KIKFoE2alN8
key:                  floskell-0.10.8-79PNgepw182KIKFoE2alN8
license:              BSD-3-Clause
copyright:
    2014 Chris Done, 2015 Andrew Gibiansky, 2016-2023 Enno Cramer

maintainer:           ecramer@memfrob.de
author:
    Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker, Enno Cramer

stability:            Unstable
homepage:             https://github.com/ennocramer/floskell
synopsis:             A flexible Haskell source code pretty printer
description:
    A flexible Haskell source code pretty printer.

    See the Github page for usage\/explanation: <https://github.com/ennocramer/floskell>

category:             Development
abi:                  889ec061adc2989068e65df61587458c
exposed:              True
exposed-modules:
    Floskell Floskell.Attoparsec Floskell.Buffer Floskell.Comments
    Floskell.Config Floskell.ConfigFile Floskell.Fixities
    Floskell.Imports Floskell.Pretty Floskell.Printers Floskell.Styles
    Floskell.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floskell
hs-libraries:         HSfloskell-0.10.8-79PNgepw182KIKFoE2alN8
depends:
    aeson-2.1.2.1-6q2KNYwRaL29rPm6MMaiUC
    attoparsec-0.14.4-AfQEBsI4KfUBbsB9NxUVAd base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy directory-1.3.7.1
    filepath-1.4.2.2 haskell-src-exts-1.23.1-8VairL9LZyWHTvO3L4BRQe
    monad-dijkstra-0.1.1.5-Bj12Inh84ChIj56B6DRJlw mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-3NcLl7S6t7kAuh7l4Ieeoo
    utf8-string-1.0.2-FAQSGuIUGqDKZx6mH04y15

haddock-interfaces:   /usr/share/doc/haskell-floskell/html/floskell.haddock
haddock-html:         /usr/share/doc/haskell-floskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-floskell-0.10.8-132-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-floskell.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 floskell
version:              0.10.8
visibility:           public
id:                   floskell-0.10.8-BlNgiQyveb89rCJRtBtSvF
key:                  floskell-0.10.8-BlNgiQyveb89rCJRtBtSvF
license:              BSD-3-Clause
copyright:
    2014 Chris Done, 2015 Andrew Gibiansky, 2016-2023 Enno Cramer

maintainer:           ecramer@memfrob.de
author:
    Chris Done, Andrew Gibiansky, Tobias Pflug, Pierre Radermecker, Enno Cramer

stability:            Unstable
homepage:             https://github.com/ennocramer/floskell
synopsis:             A flexible Haskell source code pretty printer
description:
    A flexible Haskell source code pretty printer.

    See the Github page for usage\/explanation: <https://github.com/ennocramer/floskell>

category:             Development
abi:                  fdd5f62c875830e637ce16425d9a5335
exposed:              True
exposed-modules:
    Floskell Floskell.Attoparsec Floskell.Buffer Floskell.Comments
    Floskell.Config Floskell.ConfigFile Floskell.Fixities
    Floskell.Imports Floskell.Pretty Floskell.Printers Floskell.Styles
    Floskell.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
library-dirs:         /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/floskell-0.10.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-floskell
hs-libraries:         HSfloskell-0.10.8-BlNgiQyveb89rCJRtBtSvF
depends:
    aeson-2.1.2.1-8kv8xeVfmZaCzdZG9aqfKb
    attoparsec-0.14.4-GuMPfMcqjBDDq1IerlxPtw base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.2-8yRIq8kwMNHG7OFJsT5Ayy directory-1.3.7.1
    filepath-1.4.2.2 haskell-src-exts-1.23.1-Hu7Z52lGhxr1PGV3cv3Mj4
    monad-dijkstra-0.1.1.5-5pdFVgGoQyMLPBoAScIbpC mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-IhcdMC6aki1KSQ4zttUKBR
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm

haddock-interfaces:   /usr/share/doc/haskell-floskell/html/floskell.haddock
haddock-html:         /usr/share/doc/haskell-floskell/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
